@@ -253,6 +253,7 @@ static void SaveAs( GtkWidget *widget, GtkWidget *notebook )
 		if( tmp )	
 			gtk_window_set_title( GTK_WINDOW( window ), g_strconcat( "X2: ", tmp->Name, NULL ) );
 	}
+
 	gtk_widget_destroy( SaveAsDialog );
 }
 
@@ -369,32 +370,6 @@ static void Jump( GtkWidget *widget, GtkWidget *notebook )
 	}
 }
 
-static void Template( GtkWidget *widget, GtkWidget *notebook )
-{
-	gchar *templates = g_build_filename( g_get_home_dir( ), "/.config/X2/templates/", NULL );
-	GDir *d = g_dir_open( templates, 0, NULL );
-	const gchar *dir = g_dir_read_name( d );	
-
-	if( dir == NULL )
-		return;
-
-	struct node *tmp = g_object_get_data( G_OBJECT( gtk_notebook_get_nth_page( GTK_NOTEBOOK( notebook ), gtk_notebook_get_current_page( GTK_NOTEBOOK( notebook ) ) ) ), "document" );
-
-	Populate_CMB( tmp->templatecmb );
-
-	if( gtk_widget_get_visible( tmp->templatebox ) )
-		gtk_widget_hide( tmp->templatebox );
-	else
-	{
-		gtk_widget_show_all( tmp->templatebox );
-		gtk_widget_hide( tmp->JumpBox );
-		gtk_widget_hide( tmp->ReplaceBox );
-		gtk_widget_hide( tmp->SearchBox );
-		gtk_widget_grab_focus( tmp->templatecmb );
-		gtk_combo_box_set_active( GTK_COMBO_BOX( tmp->templatecmb ), 0 );
-	}
-}
-
 static void Cmd( GtkWidget *widget, GtkWidget *notebook )
 {
 	struct node *tmp = g_object_get_data( G_OBJECT( gtk_notebook_get_nth_page( GTK_NOTEBOOK( notebook ), gtk_notebook_get_current_page( GTK_NOTEBOOK( notebook ) ) ) ), "document" );
@@ -405,148 +380,6 @@ static void Cmd( GtkWidget *widget, GtkWidget *notebook )
 		gtk_widget_show_all( tmp->TermScroll );
 }
 
-static void close_prefs( GtkWidget *widget, struct prefs *pref )
-{
-	if( gtk_widget_get_visible( GTK_WIDGET( pref->Prefs_Win ) ) )
-		gtk_widget_destroy( GTK_WIDGET( pref->Prefs_Win ) );
-
-	// Lock off!
-	prefs_win_open = FALSE;
-}
-
-static void save_prefs( GtkWidget *widget, struct prefs *pref )
-{
-	GError *error = NULL;
-	gchar *base = g_build_filename( g_get_home_dir( ), "/.config/X2/", NULL );
-	gchar *fn = g_build_filename( base, "X2.conf", NULL );
-
-	// Get preference values
-	gchar *programming_pref = "programmingfeatures:false\n";
-	gchar *highlighting_pref = "syntaxhighlighting:false\n";	
-	gchar *linenumbers_pref = "linenumbers:false\n";
-	gchar *terminal_pref = "terminal:false\n";
-	gchar *searchwords_pref = "searchinwords:false\n";
-	gchar *searchcasesensitive_pref = "casesensitive:false\n";
-	gchar *highlightline = "highlightline:false\n";
-	const gchar *fontnamesize = gtk_font_button_get_font_name( GTK_FONT_BUTTON( pref->Font ) );
-
-	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( pref->Programming_Check ) ) )
-		programming_pref = "programmingfeatures:true\n";
-
-	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( pref->Highlight_Check ) ) )
-		highlighting_pref = "syntaxhighlighting:true\n";
-
-	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( pref->Lines_Check ) ) )
-		linenumbers_pref = "linenumbers:true\n";
-
-	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( pref->Terminal_Check ) ) )
-		terminal_pref = "terminal:true\n";
-
-	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( pref->FindInWords ) ) )
-		searchwords_pref = "searchinwords:true\n";
-
-	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( pref->FindSensitive ) ) )
-		searchcasesensitive_pref = "casesensitive:true\n";
-
-	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( pref->HighlightLine ) ) )
-		highlightline = "highlightline:true\n";
-
-	gsize bytes;
-	GIOChannel *write = g_io_channel_new_file( fn, "w", &error );
-	g_io_channel_write_chars( write, programming_pref, -1, &bytes, NULL );
-	g_io_channel_write_chars( write, highlighting_pref, -1, &bytes, NULL );
-	g_io_channel_write_chars( write, linenumbers_pref, -1, &bytes, NULL );
-	g_io_channel_write_chars( write, terminal_pref, -1, &bytes, NULL );
-	g_io_channel_write_chars( write, searchwords_pref, -1, &bytes, NULL );
-	g_io_channel_write_chars( write, searchcasesensitive_pref, -1, &bytes, NULL );
-	g_io_channel_write_chars( write, highlightline, -1, &bytes, NULL );
-	g_io_channel_write_chars( write, fontnamesize, -1, &bytes, NULL );
-	g_io_channel_close( write );
-
-	g_free( error );
-	g_free( write );
-	gtk_widget_destroy( GTK_WIDGET( pref->Prefs_Win ) );
-
-	// Lock off!
-	prefs_win_open = FALSE;
-}
-
-static void set_default_prefs( )
-{
-	GError *error = NULL;
-	gchar *base = g_build_filename( g_get_home_dir( ), "/.config/X2/", NULL );
-	gchar *fn = g_build_filename( base, "X2.conf", NULL );
-	gsize bytes;
-	gchar *programming_pref = "programmingfeatures:false\n";
-	gchar *highlighting_pref = "syntaxhighlighting:false\n";	
-	gchar *linenumbers_pref = "linenumbers:false\n";
-	gchar *terminal_pref = "terminal:false\n";
-	gchar *searchwords_pref = "searchinwords:false\n";
-	gchar *searchcasesensitive_pref = "casesensitive:false\n";
-	gchar *highlightline = "highlightline:false\n";
-	const gchar *fontnamesize = "Sans 10\n";
-
-	GIOChannel *write = g_io_channel_new_file( fn, "w", &error );
-
-	g_io_channel_write_chars( write, programming_pref, -1, &bytes, NULL );
-	g_io_channel_write_chars( write, highlighting_pref, -1, &bytes, NULL );
-	g_io_channel_write_chars( write, linenumbers_pref, -1, &bytes, NULL );
-	g_io_channel_write_chars( write, terminal_pref, -1, &bytes, NULL );
-	g_io_channel_write_chars( write, searchwords_pref, -1, &bytes, NULL );
-	g_io_channel_write_chars( write, searchcasesensitive_pref, -1, &bytes, NULL );
-	g_io_channel_write_chars( write, highlightline, -1, &bytes, NULL );
-	g_io_channel_write_chars( write, fontnamesize, -1, &bytes, NULL );
-	
-	g_io_channel_close( write );
-	g_free( write );
-	/*g_free( error );*/
-}
-
-struct settings *load_prefs( struct settings *sets )
-{
-	gchar *base = g_build_filename( g_get_home_dir( ), "/.config/X2/", NULL );
-	gchar *fn = g_build_filename( base, "X2.conf", NULL );
-
-	if( !g_file_test( fn, G_FILE_TEST_EXISTS ) )
-		g_file_make_directory_with_parents( g_file_new_for_path( base ), FALSE, NULL );
-
-	if( !g_file_test( fn, G_FILE_TEST_EXISTS ) )
-		set_default_prefs( );
-
-	gchar *line;
-	GIOChannel *read;
-	read = g_io_channel_new_file( fn, "r", NULL );
-
-	g_io_channel_read_line( read, &line, NULL, NULL, NULL );
-	sets->prog_features = line;
-
-	g_io_channel_read_line( read, &line, NULL, NULL, NULL );
-	sets->highlighting = line;
-
-	g_io_channel_read_line( read, &line, NULL, NULL, NULL );
-	sets->lines = line;
-
-	g_io_channel_read_line( read, &line, NULL, NULL, NULL );
-	sets->terminal = line;
-
-	g_io_channel_read_line( read, &line, NULL, NULL, NULL );
-	sets->find_in_words = line;
-
-	g_io_channel_read_line( read, &line, NULL, NULL, NULL );
-	sets->find_sensitive = line;
-
-	g_io_channel_read_line( read, &line, NULL, NULL, NULL );
-	sets->highlightline = line;
-
-	g_io_channel_read_line( read, &line, NULL, NULL, NULL );
-	sets->font = line;
-
-	g_io_channel_close( read );
-	g_free( read );
-
-	return( sets );
-}
-
 static void Enable_Programming_Check_Buttons( GtkWidget *widget, struct prefs *pref )
 {
 	if( !gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( pref->Programming_Check ) ) )
@@ -570,153 +403,6 @@ static void Enable_Programming_Check_Buttons( GtkWidget *widget, struct prefs *p
 	}
 } 
 
-static void Prefs( GtkWidget *widget )
-{
-	if( prefs_win_open )
-		return;
-	
-	// Lock on!
-	prefs_win_open = TRUE;
-		
-	struct prefs *pref = g_malloc( sizeof( struct prefs ) ); 
-
-	// Create widgets
-	pref->Prefs_Win = gtk_window_new( GTK_WINDOW_TOPLEVEL );
-	pref->Box = gtk_vbox_new( FALSE, 0 );
-	pref->General_Box = gtk_vbox_new( FALSE, 0 );
-	pref->Appearence_Box = gtk_vbox_new( FALSE, 0 );
-	pref->Notes = gtk_notebook_new( );
-	pref->BtnBox = gtk_hbutton_box_new( );
-	pref->Apply = gtk_button_new_from_stock( GTK_STOCK_APPLY );
-	pref->Cancel = gtk_button_new_from_stock( GTK_STOCK_CANCEL );
-	pref->GeneralLbl = gtk_label_new( "General" );
-	pref->AppearenceLbl = gtk_label_new( "Appearance" );
-	pref->LicenceLbl = gtk_label_new( "Licence" );
-	pref->Licence_Buffer = gtk_text_buffer_new( NULL );
-	pref->Licence = gtk_text_view_new_with_buffer( GTK_TEXT_BUFFER( pref->Licence_Buffer ) );
-	pref->Scroller = gtk_scrolled_window_new( NULL, NULL );
-	pref->Font = gtk_font_button_new( );	
-	pref->FontFrame = gtk_frame_new( "Font" );
-	pref->UIBox = gtk_vbox_new( FALSE, 0 );
-	pref->Programming_Box = gtk_vbox_new( FALSE, 0 );
-	pref->ProgrammingFrame = gtk_frame_new( "Programming Features" );
-	pref->Programming_Check = gtk_check_button_new_with_label( "Enable programming features" );
-	pref->Highlight_Check = gtk_check_button_new_with_label( "Enable Syntax Highlighting" );
-	pref->Lines_Check = gtk_check_button_new_with_label( "Enable Line Numbers" );	
-	pref->Terminal_Check = gtk_check_button_new_with_label( "Enable Terminal" );
-	pref->FindFrame = gtk_frame_new( "Search Preferences" );
-	pref->FindInWords = gtk_check_button_new_with_label( "Search inside words" );
-	pref->FindSensitive = gtk_check_button_new_with_label( "Search case sensitive" );
-	pref->FindBox = gtk_vbox_new( FALSE, 0 );
-	pref->HighlightLine = gtk_check_button_new_with_label( "Highlight current line" );
-	
-	// Set widget properties
-	gtk_window_set_title( GTK_WINDOW( pref->Prefs_Win ), "X2: Preferences" );
-	gtk_notebook_append_page( GTK_NOTEBOOK( pref->Notes ), pref->General_Box, pref->GeneralLbl );
-	gtk_notebook_append_page( GTK_NOTEBOOK( pref->Notes ), pref->Appearence_Box, pref->AppearenceLbl );
-	gtk_notebook_append_page( GTK_NOTEBOOK( pref->Notes ), pref->Scroller, pref->LicenceLbl );
-	gtk_button_box_set_layout( GTK_BUTTON_BOX( pref->BtnBox ), GTK_BUTTONBOX_END );
-	gtk_font_button_set_title( GTK_FONT_BUTTON( pref->Font ), "Choose font" );
-
-	// Load prefs
-	if( g_strrstr( sets->prog_features, ":true" ) )
-		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( pref->Programming_Check ), TRUE );
-	else
-		Enable_Programming_Check_Buttons( NULL, pref );
-
-	if( g_strrstr( sets->highlighting, ":true" ) )
-		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( pref->Highlight_Check ), TRUE );
-
-	if( g_strrstr( sets->lines, ":true" ) )
-		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( pref->Lines_Check ), TRUE );
-
-	if( g_strrstr( sets->terminal, ":true" ) )
-		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( pref->Terminal_Check ), TRUE );
-
-	if( g_strrstr( sets->find_in_words, ":true" ) )
-		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( pref->FindInWords ), TRUE );
-
-	if( g_strrstr( sets->find_sensitive, ":true" ) )
-		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( pref->FindSensitive ), TRUE );
-
-	if( g_strrstr( sets->highlightline, ":true" ) )
-		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( pref->HighlightLine ), TRUE );
-
-
-	gtk_font_button_set_font_name( GTK_FONT_BUTTON( pref->Font ), sets->font );
-
-	// Add and pack widgets
-	gtk_container_add( GTK_CONTAINER( pref->Prefs_Win ), GTK_WIDGET( pref->Box ) );
-	gtk_container_add( GTK_CONTAINER( pref->Scroller ), GTK_WIDGET( pref->Licence ) );
-	gtk_scrolled_window_set_policy( GTK_SCROLLED_WINDOW( pref->Scroller ), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );	
-	gtk_box_pack_start( GTK_BOX( pref->Box ), pref->Notes, TRUE, TRUE, 0 );
-	gtk_box_pack_start( GTK_BOX( pref->Box ), pref->BtnBox, FALSE, FALSE, 0 );
-	gtk_box_pack_start( GTK_BOX( pref->BtnBox ), pref->Cancel, FALSE, FALSE, 0 );
-	gtk_box_pack_start( GTK_BOX( pref->BtnBox ), pref->Apply, FALSE, FALSE, 0 );
-
-	gtk_box_pack_start( GTK_BOX( pref->General_Box ), pref->ProgrammingFrame, FALSE, FALSE, 0 );
-	gtk_box_pack_start( GTK_BOX( pref->General_Box ), pref->FindFrame, FALSE, FALSE, 0 );
-	gtk_box_pack_start( GTK_BOX( pref->Appearence_Box ), pref->FontFrame, FALSE, FALSE, 0 );
-	gtk_container_add( GTK_CONTAINER( pref->FontFrame ), GTK_WIDGET( pref->Font ) );
-	gtk_container_add( GTK_CONTAINER( pref->ProgrammingFrame ), GTK_WIDGET( pref->Programming_Box ) );
-	gtk_container_add( GTK_CONTAINER( pref->FindFrame ), GTK_WIDGET( pref->FindBox ) );
-	gtk_box_pack_start( GTK_BOX( pref->Programming_Box ), pref->Programming_Check, FALSE, FALSE, 0 );
-	gtk_box_pack_start( GTK_BOX( pref->Programming_Box ), pref->Highlight_Check, FALSE, FALSE, 0 );
-	gtk_box_pack_start( GTK_BOX( pref->Programming_Box ), pref->Lines_Check, FALSE, FALSE, 0 );
-	gtk_box_pack_start( GTK_BOX( pref->Programming_Box ), pref->Terminal_Check, FALSE, FALSE, 0 );
-	gtk_box_pack_start( GTK_BOX( pref->Programming_Box ), pref->HighlightLine, FALSE, FALSE, 0 );
-	gtk_box_pack_start( GTK_BOX( pref->FindBox ), pref->FindInWords, FALSE, FALSE, 0 );
-	gtk_box_pack_start( GTK_BOX( pref->FindBox ), pref->FindSensitive, FALSE, FALSE, 0 );
-	
-	// Connect signals
-	g_signal_connect( pref->Prefs_Win, "delete-event", G_CALLBACK( close_prefs ), pref );
-	g_signal_connect( pref->Apply, "clicked", G_CALLBACK( save_prefs ), pref );
-	g_signal_connect( pref->Cancel, "clicked", G_CALLBACK( close_prefs ), pref );
-	g_signal_connect( pref->Programming_Check, "toggled", G_CALLBACK( Enable_Programming_Check_Buttons ), pref );
-
-	// Show licence
-	GtkTextIter End;
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "Copyright (c) 2011, Rock Computing\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "All rights reserved.\n\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "Redistribution and use in source and binary forms, with or without\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "modification, are permitted provided that the following conditions are met:\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "\n\t* Redistributions of source code must retain the above copyright\n\tnotice, this list of conditions and the following disclaimer.\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "\n\t* Redistributions in binary form must reproduce the above copyright\n\tnotice, this list of conditions and the following disclaimer in the\n\tdocumentation and/or other materials provided with the distribution.\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "\n\t* Neither the name Rock Computing nor the names of its contributors\n\tmay be used to endorse or promote products derived from this\n\tsoftware without specific prior written permission.\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "\n\nTHIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\" AND\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "DISCLAIMED. IN NO EVENT SHALL ROCK COMPUTING BE LIABLE FOR ANY\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS\n", -1 );
-	gtk_text_buffer_get_end_iter( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End );
-	gtk_text_buffer_insert( GTK_TEXT_BUFFER( pref->Licence_Buffer ), &End, "SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n", -1 );
-	gtk_text_view_set_editable( GTK_TEXT_VIEW( pref->Licence ), FALSE );
-
-	// Show widgets
-	gtk_widget_show( pref->Prefs_Win );
-	gtk_widget_show_all( pref->Box );
-}
-
 static void S1( GtkEntry *entry, GtkEntryIconPosition icon_pos, GdkEvent *event, struct search_data *sd ) { Search( sd ); }
 static void S2( GtkEntry *entry, struct search_data *sd ) { Search( sd ); }
 
@@ -850,36 +536,53 @@ static void BufferChanged( GtkWidget *widget, struct node *tmp )
 static gboolean destroy( GtkWidget *widget, GdkEvent *event, GtkWidget *notebook ) 
 { 
 	gint pages = gtk_notebook_get_n_pages( GTK_NOTEBOOK( notebook ) ) -1;
-	gtk_main_quit( );
-	gint i;
+	gint i = 0;
+	GtkWidget *label = gtk_label_new( "There are unsaved files.\nAre you sure you want to quit?" );
+	gboolean saved = TRUE;
+
+	gtk_notebook_set_current_page( GTK_NOTEBOOK( notebook ), i );
+	GtkWidget *warning = gtk_dialog_new_with_buttons(
+	"Really quit?",
+        NULL,
+        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+        GTK_STOCK_YES, GTK_RESPONSE_YES,
+        GTK_STOCK_NO, GTK_RESPONSE_NO,
+        NULL );
+	gtk_container_add( GTK_CONTAINER( GTK_DIALOG( warning )->vbox), label );
+	gtk_widget_show( GTK_WIDGET( label ) );
+	gtk_button_box_set_layout( GTK_DIALOG( warning )->action_area, GTK_BUTTONBOX_EDGE );
 
 	for( i = 0; i <= pages; i++ )
 	{
 		struct node *tmp = g_object_get_data( G_OBJECT( gtk_notebook_get_nth_page( GTK_NOTEBOOK( notebook ), gtk_notebook_get_current_page( GTK_NOTEBOOK( notebook ) ) ) ), "document" );
 
 		if( gtk_text_buffer_get_modified( GTK_TEXT_BUFFER( tmp->Buffer ) ) )
-		{
-			gtk_notebook_set_current_page( GTK_NOTEBOOK( notebook ), i );
-			GtkWidget *warning = gtk_dialog_new_with_buttons(
-			"Save file?",
-                        NULL,
-                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                        GTK_STOCK_YES,
-                        GTK_RESPONSE_YES,
-                        GTK_STOCK_NO,
-                        GTK_RESPONSE_NO,
-                        NULL );
+			saved = FALSE;
 
-			gint result = gtk_dialog_run( GTK_DIALOG( warning ) );
-			
-			if( result == GTK_RESPONSE_YES )
-				Save( NULL, notebook );
-
-			gtk_widget_destroy( warning );
-		}
+		gtk_notebook_set_current_page( GTK_NOTEBOOK( notebook ), i+1 );
 	}
 
-	return( TRUE );
+	if( !saved )
+	{
+		gint result = gtk_dialog_run( GTK_DIALOG( warning ) );
+			
+		switch( result )
+		{
+			case GTK_RESPONSE_YES:
+				gtk_widget_destroy( warning );
+				gtk_main_quit( );
+				return( FALSE );
+
+			case GTK_RESPONSE_NO:
+				gtk_widget_destroy( warning );
+				return( TRUE );
+		}
+
+	}
+
+	gtk_widget_destroy( warning );
+	gtk_main_quit( );
+	return( FALSE );
 }
 
 static void drag_data_received_handler( GtkWidget *widget, GdkDragContext *context, gint x, gint y, GtkSelectionData *selection_data, guint target_type, guint time, GtkWidget *notebook )
@@ -936,7 +639,16 @@ static void write_file( struct node *tmp )
 {
 	GtkTextIter StartIter, EndIter;
 	gtk_text_buffer_get_bounds( GTK_TEXT_BUFFER( tmp->Buffer ), &StartIter, &EndIter );
+
+	int r = access( tmp->Name, R_OK );
+	int w = access( tmp->Name, W_OK );
+	int x = access( tmp->Name, X_OK );
+
 	g_file_set_contents( tmp->Name, gtk_text_buffer_get_text( GTK_TEXT_BUFFER( tmp->Buffer ), &StartIter, &EndIter, TRUE ), -1, NULL );
+
+	if( r == 0 && w == 0 && x == 0 )
+		chmod( tmp->Name, S_IRWXU );	
+
 }
 
 static void Set_Title( GtkWidget *notebook, gpointer page, guint page_num, gpointer user_data )
@@ -961,6 +673,7 @@ static GtkWidget *open_with( gchar *fn, GtkWidget *notebook )
 	gtk_text_buffer_set_modified( GTK_TEXT_BUFFER( tmp->Buffer ), FALSE );
 
 	gtk_window_set_title( GTK_WINDOW( window ), g_strconcat( "X2: ", tmp->Name, NULL ) );
+
 	// Syntax highlighting
 	highlight_code( tmp );
 	g_free( contents );
@@ -984,12 +697,13 @@ static GtkWidget *open_from( gchar *fn, GtkWidget *notebook )
 	gtk_text_buffer_set_text( GTK_TEXT_BUFFER( tmp->Buffer ), contents, -1 );
 	gtk_label_set_text( GTK_LABEL( tmp->Label ), g_strconcat( g_path_get_basename( tmp->Name ), "* ", NULL ) );
 	gtk_text_buffer_set_modified( GTK_TEXT_BUFFER( tmp->Buffer ), FALSE );
-
 	gtk_window_set_title( GTK_WINDOW( window ), g_strconcat( "X2: ", tmp->Name, NULL ) );
+
 	// Syntax highlighting
 	highlight_code( tmp );
 	g_free( contents );
 	gtk_text_buffer_set_modified( GTK_TEXT_BUFFER( tmp->Buffer ), TRUE );
+
 	return( tmp->Doc );
 }
 
@@ -1004,27 +718,6 @@ static void highlight_code( struct node *tmp )
 	}
 }
 
-static void Populate_CMB( GtkWidget *cmb )
-{
-	gchar *templates = g_build_filename( g_get_home_dir( ), "/.config/X2/templates/", NULL );
-	GDir *d = g_dir_open( templates, 0, NULL );
-
-	// Following code found here: http://www.gtkforums.com/viewtopic.php?t=3425
-	GtkTreeModel *store = gtk_combo_box_get_model( GTK_COMBO_BOX( cmb ) );
-	gtk_list_store_clear( GTK_LIST_STORE( store ) );
-
-	for( ; ; )
-	{
-		const gchar *tmp = g_dir_read_name( d );	
-
-		if( tmp != NULL )
-			gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT( cmb ), tmp );
-
-		else
-			break;
-	}
-}
-
 static void Catch_Keypress( GtkWidget *widget, GdkEvent *event, GtkWidget *notebook )
 {
 	GdkEventKey *gek = ( GdkEventKey * ) event;
@@ -1037,31 +730,4 @@ static void Catch_Keypress( GtkWidget *widget, GdkEvent *event, GtkWidget *noteb
 
 	else if( ( gek->keyval == GDK_W ) && ( gek->state & GDK_CONTROL_MASK ) )
 		SaveTemplate( widget, notebook );
-}
-
-static void LoadTemplate( GtkWidget *widget, GtkWidget *notebook )
-{
-	struct node *tmp = g_object_get_data( G_OBJECT( gtk_notebook_get_nth_page( GTK_NOTEBOOK( notebook ), gtk_notebook_get_current_page( GTK_NOTEBOOK( notebook ) ) ) ), "document" );
-	gchar *template = g_build_filename( g_get_home_dir( ), "/.config/X2/templates/", gtk_combo_box_text_get_active_text( GTK_COMBO_BOX_TEXT( tmp->templatecmb ) ), NULL );
-	open_from( template, notebook );
-	gtk_widget_hide( tmp->templatebox );
-}
-
-static void SaveTemplate( GtkWidget *widget, GtkWidget *notebook )	
-{
-	struct node *tmp = g_object_get_data( G_OBJECT( gtk_notebook_get_nth_page( GTK_NOTEBOOK( notebook ), gtk_notebook_get_current_page( GTK_NOTEBOOK( notebook ) ) ) ), "document" );
-
-	if( !g_strrstr( g_path_get_basename( tmp->Name ), "." ) )
-		return;
-
-	// Split file name up
-	gchar **s = g_strsplit( g_path_get_basename( tmp->Name ), ".", 2 );
-	gchar *t = s[ 1 ];
-	gchar *fn = g_strconcat( "template.", t, NULL );
-	gchar *template = g_build_filename( g_get_home_dir( ), "/.config/X2/templates/", fn, NULL );
-	g_print( "%s\n", template );
-
-	GtkTextIter StartIter, EndIter;
-	gtk_text_buffer_get_bounds( GTK_TEXT_BUFFER( tmp->Buffer ), &StartIter, &EndIter );
-	g_file_set_contents( template, gtk_text_buffer_get_text( GTK_TEXT_BUFFER( tmp->Buffer ), &StartIter, &EndIter, TRUE ), -1, NULL );
 }
\ No newline at end of file
